@@ -7,7 +7,7 @@ use utf8;
 
 BEGIN {
 	$Types::XSD::Lite::AUTHORITY = 'cpan:TOBYINK';
-	$Types::XSD::Lite::VERSION   = '0.003';
+	$Types::XSD::Lite::VERSION   = '0.004';
 }
 
 use B qw(perlstring);
@@ -298,9 +298,10 @@ sub facet
 	
 	my $inline_generator = sub
 	{
-		my %p = @_;
+		my %p_not_destroyed = @_;
 		return sub {
 			local $T = $_[0]->parent;
+			my %p    = %p_not_destroyed;  # copy;
 			my $var  = $_[1];
 			my $r    = sprintf(
 				'(%s)',
@@ -708,7 +709,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013 by Toby Inkster.
+This software is copyright (c) 2013-2014 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
